@@ -41,15 +41,15 @@ rmcorr <- function(participant, measure1, measure2, dataset,
     args <- as.list(match.call())
     
     Participant <- eval(args$participant, dataset, parent.frame())
-    if (class(Participant) == "character"){
+    if ((class(Participant) == "character")&(length(Participant) == 1)){
         Participant <- get(Participant, dataset)
     }
     Measure1 <- eval(args$measure1, dataset, parent.frame())
-    if (class(Measure1) == "character"){
+    if ((class(Measure1) == "character")&(length(Measure1) == 1)){
         Measure1 <- get(Measure1, dataset)
     }
     Measure2 <- eval(args$measure2, dataset, parent.frame())
-    if (class(Measure2) == "character"){
+    if ((class(Measure2) == "character")&(length(Measure2) == 1)){
         Measure2 <- get(Measure2, dataset)
     }
     
